pub struct CreateModelParams<'a> {
pub hf_repo_id: &'a str,
pub name: &'a str,
pub org: &'a str,
pub family: &'a str,
pub parameter_class: &'a str,
pub format: &'a str,
pub gguf_file: Option<&'a str>,
pub modality: Option<&'a str>,
pub description: Option<&'a str>,
pub approx_size_bytes: Option<i64>,
}Expand description
Parameters for registering a new model into the catalog via
create_model. The new row is private to the calling user.
Fields
hf_repo_id: &'a strname: &'a strorg: &'a strfamily: &'a strparameter_class: &'a strformat: &'a strgguf_file: Option<&'a str>modality: Option<&'a str>description: Option<&'a str>approx_size_bytes: Option<i64>Trait Implementations
Sourceimpl<'a> Clone for CreateModelParams<'a>
impl<'a> Clone for CreateModelParams<'a>
Sourcefn clone(&self) -> CreateModelParams<'a>
fn clone(&self) -> CreateModelParams<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for CreateModelParams<'a>
impl<'a> Debug for CreateModelParams<'a>